==> asmtools_7.0-b09.orig.tar.gz: asmtools-7.0-b09/src/org/openjdk/asmtools/jdis/TrapData.java <==
/*
 * Copyright (c) 1996, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.asmtools.jdis;

import java.io.DataInputStream;
import java.io.IOException;

/**
 * Exception table entry (JVMS 4.7.3 The Code Attribute) describes one exception handler
 * in the code array {@link CodeData}.
 */
class TrapData {

    int num;

    // exception_table
    int start_pc,       // u2
        end_pc,         // u2
        handler_pc,     // u2
        catch_cpx;      // u2

    public TrapData(DataInputStream in, int num) throws IOException {
        this.num = num;
        start_pc = in.readUnsignedShort();
        end_pc = in.readUnsignedShort();
        handler_pc = in.readUnsignedShort();
        catch_cpx = in.readUnsignedShort();
    }

    /* returns recommended identifier
     */
    public String ident() {
        return "t" + num;
    }
}

==> asmtools-8.0-b09.tar.gz: asmtools-8.0-b09/src/org/openjdk/asmtools/jdis/TrapData.java <==
/*
 * Copyright (c) 1996, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.asmtools.jdis;

import java.io.DataInputStream;
import java.io.IOException;

/**
 * Exception table entry (JVMS 4.7.3 The Code Attribute) describes one exception handler
 * in the code array {@link CodeData}.
 */
class TrapData {

    int num;

    // exception_table
    int start_pc,       // u2
        end_pc,         // u2
        handler_pc,     // u2
        catch_cpx;      // u2

    public TrapData(DataInputStream in, int num) throws IOException {
        this.num = num;
        start_pc = in.readUnsignedShort();
        end_pc = in.readUnsignedShort();
        handler_pc = in.readUnsignedShort();
        catch_cpx = in.readUnsignedShort();
    }

    // returns recommended identifier
    public String id() {
        return "T" + num;
    }
}
